[Hectiq lab](https://lab.hectiq.ai) is a platform for tracking machine learning experiments. The `pyhectiqlab` is the python client to connect with the lab.

## Links

- [Official documentation](https://docs.hectiq.ai)
- [Platform](https://lab.hectiq.ai)
